Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthieu Aubry <mattab@users.noreply.github.com>2016-09-29 05:03:02 +0300
committerGitHub <noreply@github.com>2016-09-29 05:03:02 +0300
commitbd5217287e84d8a2fdc457dd07ce63d78c5835b4 (patch)
treeb0c4121eda233d3bfeeae29a482dc8f5a3d6304b /plugins/LanguagesManager/Commands/CreatePull.php
parenta8f682a6039e9b765e248c6be531cce54a7903d1 (diff)
2.16.3-rc1 (#10590)2.16.3-rc1
* Fix depraction test: use assertDeprecatedMethodIsRemovedInPiwik3 * Fix Scheduled Reports sent one hour late in daylight saving timezones (#10443) * convert hour to send report to/from UTC, to ensure it isn't affected by daylight savings * adds update script to change existing scheduled reports to use utc time * code improvement * adds missing param * Added new event Archiving.makeNewArchiverObject to allow customising plugin archiving (#10366) * added hook to alllow plugin archiving prevention * cr code style notes * reworked PR to fit CR suggestions * added PHPDoc for hook * Event description more consistent * UI tests: minor changes * Comment out Visitor Log UI tests refs #10536 * Adds test checking if all screenshots are stored in lfs * removed screenshots not stored in lfs * readds screenshots to lfs * 2.16.3-b4 * Issue translation updates against 2.x-dev * language update * Fix bug in widget list remove where the JSON object becomes array * 2.16.3-rc1 * console command custom-piwik-js:update should work when directory is writable and file does not exist yet (#10576) * followup #10449 * Fix test (cherry picked from commit fac3d63) * Prevent chmod(): No such file or directory * Automatically update all marketplace plugins when updating Piwik (#10527) * update plugins and piwik at the same time * make sure plugins are updated with piwik * use only one try/catch * reload plugin information once it has been installed * make sure to clear caches after an update * fix ui tests * make sure to use correct php version without any extras * Additional informations passed in the hook "isExcludedVisit" (issue #10415) (#10564) * Additional informations passed in the hook "isExcludedVisit" (issue #10415) * Added better description to the new parameters * Update VisitExcluded.php * Remove two parameters not needed as better to use the Request object * Update VisitExcluded.php * remove extra two parameters in VisitExcluded constructor to prevent confusion (#10593) * Update our libs to latest https://github.com/piwik/piwik/issues/10526 * Update composer libraries to latest https://github.com/piwik/piwik/issues/10526 * Update log analytics to latest * When updating the config file failed (or when any other file is not writable...), the Updater (for core or plugins) will now automatically throw an error and cancel the update (#10423) * When updating the config file failed (or when any other file is not writable...), the Updater (for core or plugins) will now automatically throw an error and cancel the update * add integration test to check the correct exception is thrown when config not writabel * New integration test for updater * Make test better * When opening the visitor profile, do not apply the segment (#10533) * When opening the visitor profile, do not apply the segment * added ui test for profile but does work for me * next try to make ui test work * add expected screenshot * added missing doc
Diffstat (limited to 'plugins/LanguagesManager/Commands/CreatePull.php')
-rw-r--r--plugins/LanguagesManager/Commands/CreatePull.php18
1 files changed, 10 insertions, 8 deletions
diff --git a/plugins/LanguagesManager/Commands/CreatePull.php b/plugins/LanguagesManager/Commands/CreatePull.php
index af46dc7000..fca1fc76aa 100644
--- a/plugins/LanguagesManager/Commands/CreatePull.php
+++ b/plugins/LanguagesManager/Commands/CreatePull.php
@@ -19,6 +19,8 @@ use Symfony\Component\Console\Output\OutputInterface;
*/
class CreatePull extends TranslationBase
{
+ const GIT_BASE_BRANCH = '2.x-dev';
+
protected function configure()
{
$this->setName('translations:createpull')
@@ -38,7 +40,7 @@ class CreatePull extends TranslationBase
return;
}
- $unpushedCommits = shell_exec('git log origin/master..HEAD');
+ $unpushedCommits = shell_exec('git log origin/' . self::GIT_BASE_BRANCH . '..HEAD');
if (!empty($unpushedCommits)) {
@@ -49,7 +51,7 @@ class CreatePull extends TranslationBase
chdir(PIWIK_DOCUMENT_ROOT);
shell_exec('
- git checkout -f master > /dev/null 2>&1
+ git checkout -f ' . self::GIT_BASE_BRANCH . ' > /dev/null 2>&1
git pull > /dev/null 2>&1
git submodule init > /dev/null 2>&1
git submodule update > /dev/null 2>&1
@@ -60,7 +62,7 @@ class CreatePull extends TranslationBase
chdir(PIWIK_DOCUMENT_ROOT.DIRECTORY_SEPARATOR.'plugins'.DIRECTORY_SEPARATOR.$plugin);
shell_exec('
- git checkout master > /dev/null 2>&1
+ git checkout ' . self::GIT_BASE_BRANCH . ' > /dev/null 2>&1
git pull > /dev/null 2>&1
');
}
@@ -73,10 +75,10 @@ class CreatePull extends TranslationBase
shell_exec('git checkout -b translationupdates origin/translationupdates');
}
// switch to branch and update it to latest master
shell_exec('
git checkout -f translationupdates > /dev/null 2>&1
- git merge master > /dev/null 2>&1
+ git reset --hard origin/' . self::GIT_BASE_BRANCH . ' > /dev/null 2>&1
git push origin translationupdates > /dev/null 2>&1
');
@@ -105,7 +107,7 @@ class CreatePull extends TranslationBase
if (empty($changes)) {
$output->writeln("Nothing changed. Everything is already up to date.");
- shell_exec('git checkout master > /dev/null 2>&1');
+ shell_exec('git checkout ' . self::GIT_BASE_BRANCH . ' > /dev/null 2>&1');
return;
}
@@ -163,7 +165,7 @@ class CreatePull extends TranslationBase
shell_exec('git commit -m "language update ${pluginName}"');
shell_exec('git push');
- shell_exec('git checkout master > /dev/null 2>&1');
+ shell_exec('git checkout ' . self::GIT_BASE_BRANCH . ' > /dev/null 2>&1');
$this->createPullRequest($output, $title, $message);
}
@@ -195,7 +197,7 @@ class CreatePull extends TranslationBase
--stderr /dev/null \
-o /dev/null \
-u '.$username.' \
- --data "{\"title\":\"[automatic translation update] '.$title.'\",\"body\":\"'.$message.'\",\"head\":\"translationupdates\",\"base\":\"master\"}" \
+ --data "{\"title\":\"[automatic translation update] '.$title.'\",\"body\":\"'.$message.'\",\"head\":\"translationupdates\",\"base\":\"' . self::GIT_BASE_BRANCH . '\"}" \
-H "Accept: application/json" \
https://api.github.com/repos/piwik/piwik/pulls');
@@ -73,10 +75,10 @@ class CreatePull extends TranslationBase
shell_exec('git checkout -b translationupdates origin/translationupdates');
}
- // switch to branch and update it to latest master
+ // switch to branch and update it to latest $GIT_BASE_BRANCH
shell_exec('
git checkout -f translationupdates > /dev/null 2>&1